@@ -1,13 +1,13 @@
 package Sah::Schema::color::rgb24;
 
-our $DATE = '2019-07-25'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 our $schema = [str => {
     summary => 'RGB 24-digit color, a hexdigit e.g. ffcc00', # XXX also allow other forms
     match => qr/\A[0-9A-Fa-f]{6}\z/,
     'x.completion' => ['colorname'],
-    'x.perl.coerce_rules' => ['str_rgb24_from_colorname_X_or_code'],
+    'x.perl.coerce_rules' => ['From_str::rgb24_from_colorname_X_or_code'],
 }, {}];
 
 1;
@@ -25,7 +25,7 @@ Sah::Schema::color::rgb24 - RGB 24-digit color, a hexdigit e.g. ffcc00
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2019-07-25.
+This document describes version 0.004 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
